# -*- coding: utf-8 -*-
__revision__ = "$Id: setup.py 3799 2013-07-05 12:28:01Z cokelaer $"
import sys
import os
from setuptools import setup, find_packages
import glob

_MAJOR               = 0
_MINOR               = 1
_MICRO               = 4
version              = '%d.%d.%d' % (_MAJOR, _MINOR, _MICRO)
release              = '%d.%d' % (_MAJOR, _MINOR)

metainfo = {
    'authors': {'Cokelaer':('Thomas Cokelaer','cokelaer@ebi.ac.uk')},
    'version': version,
    'license' : 'GPL',
    'download_url' : ['http://pypi.python.org/pypi/bioconvert'],
    'url' : ['http://www.ebi.ac.uk/~cokelaer/bioconvert'],
    'description':'Common utilities to ease convertion between biological data format' ,
    'platforms' : ['Linux', 'Unix', 'MacOsX', 'Windows'],
    'keywords' : ['signalling pathways', 'MIDAS', 'protein interaction network', 
        'SIF', "ASP", "JSON", "NET", "cellnopt"],
    'classifiers' : [
          'Development Status :: 4 - Beta',
          'Intended Audience :: Developers',
          'Intended Audience :: Science/Research',
          'License :: OSI Approved :: GNU Library or Lesser General Public License (LGPL)',
          'Operating System :: OS Independent',
          'Programming Language :: Python :: 2.7',
          'Topic :: Software Development :: Libraries :: Python Modules',
          'Topic :: Scientific/Engineering :: Bio-Informatics',
          'Topic :: Scientific/Engineering :: Information Analysis',
          'Topic :: Scientific/Engineering :: Mathematics',
          'Topic :: Scientific/Engineering :: Physics']
    }


# TODO: files in share/data. Need a smarter mechanism (recursive)
datafiles = []
datadirs = [os.path.join('share', 'data')]
for datadir in datadirs:
    datafiles.append(
        (
            datadir, 
            [f for f in glob.glob(os.path.join(datadir, '*')) if not os.path.isdir(f)]
        )
    )


setup(
    name             = 'bioconvert',
    version          = version,
    maintainer       = metainfo['authors']['Cokelaer'][0],
    maintainer_email = metainfo['authors']['Cokelaer'][1],
    author           = metainfo['authors']['Cokelaer'][0],
    author_email     = metainfo['authors']['Cokelaer'][1],
    long_description = open("README.txt").read(),
    keywords         = metainfo['keywords'],
    description = metainfo['description'],
    license          = metainfo['license'],
    platforms        = metainfo['platforms'],
    url              = metainfo['url'],      
    download_url     = metainfo['download_url'],
    classifiers      = metainfo['classifiers'],

    # package installation
    package_dir = {'':'src'},
    packages = ['bioconvert'],

    install_requires = ['sphinx', "easydev", "cellnopt.core"],
    data_files = datafiles,

    entry_points = {
        'console_scripts': [
            'bioconvert=bioconvert.apps:bioconvert',
        ]
        },



)




