"""This module provides tools to convert a SIF file into a format appropriate to
check sign consistency with ASP tools::

    A 1 B
    A -1 B

converted to ::

    A -> B +
    A -> B -


"""

__all__ = [ "SIF2ASPnet"]



class SIF2ASPnet(object):
    """Uses cellnopt.core to read the SIF file


    """

    def __init__(self, filename):
        """.. rubric:: constructor

        :param str filename: the SIF input file name
        """
        self.filename = filename[:]
        self.sif = None
        self._reset()
        self._readsif()

    def _reset(self):
        self.nodes1 = []
        self.nodes2 = []
        self.signs = []

    def _readsif(self):
        from cellnopt.core import SIF
        self.sif = SIF(self.filename)

    def convert(self):
        """Converts the SIF reactions into NET reactions

        """
        self._reset()
        for n1, n2 ,sign in zip(self.sif.nodes1, self.sif.nodes2, self.sif.edges):
            self.nodes1.append(n1)
            self.nodes2.append(n2)
            if sign == "1": 
                self.signs.append("+")
            elif sign == "-1":
                self.signs.append("-")
            else:
                raise ValueError("Found a sign different from -1 and 1. Check your SIF file")

    def __str__(self):
        txt = ""
        for n1,n2,s in zip(self.nodes1, self.nodes2, self.signs):
            txt += "%s -> %s %s" % (n1, n2, s)
        return txt

    def write2net(self, filename):
        """Write nodes and signs into a NET format

        NET format is of the form::

            A -> B +
            A -> B -

        """
        if len(self.nodes1)>0:
            h = open(filename, "w")
            for n1,n2,s in zip(self.nodes1, self.nodes2, self.signs):
                h.write("%s -> %s %s\n" % (n1, n2, s))
            h.close()
        else:
            print("nothing to save. Is the SIF file correct ?") 




