#from cellnopt.core import readSIF





class SIF2JSON(object):
    """Converts a SIF into a JSON file given a MIDAS file

    SIF is used for topology. MIDAS is used for attributes.

    """

    def __init__(self, filename, midas):
        self.filename = filename[:]
        self.midas_filename = midas
        self.sif = None
        self.midas = None
        self.readsif()

    def readsif(self):
        from cellnopt.core import SIF
        self.sif = SIF(self.filename)

    def readMIDAS(self):
        if self.midas_filename:
            from cellnopt.core import MIDASReader
            self.midas = MIDASReader(self.midas_filename)

    def write2json(self, filename):
        self.convert()
        fh = open(filename, "w")
        fh.write(self.json)
        fh.close()

    def convert(self):# create node list
        nodes = set(self.sif.nodes1)
        nodes = nodes.union(self.sif.nodes2)

        # flet us write the nodes. as for the group it is 1 except if midas file is provided.

        json = """{"nodes":[\n"""

        nodes = list(nodes)

        for node in nodes:
            group = 1
            json += """    {"name":"%s",    "group":%s},\n""" % (node, group)
        # remoev last comma
        json = json[:-2]
        json += """\n],\n"""

        #now the links
        json += """"links":\n["""
        for n1, edge, n2 in zip(self.sif.nodes1, self.sif.edges, self.sif.nodes2):
            i1 = nodes.index(n1)
            i2 = nodes.index(n2)
            link = edge
            json += """	   {"source":%s, "target":%s, "value":1, "link":%s},\n""" % (i1, i2, link)

        # remove last comma
        json = json[:-2]
        json += """\n],\n"""

        json += "\n}"
        self.json = json[:]


